# csv2json

A command-line utility that quickly and easily converts CSVs to JSON.

## Usage

You can install csv2json using PyPi and use it as follows:

```bash
$ pip install csv2json.py
$ cat <mycsv> | csv2json -p

# See --help for more information.
```

## Help

```bash
A utility to convert CSVs to JSON quickly and easily.

optional arguments:
  -h, --help            show this help message and exit
  -i INPUT, --input INPUT
  -o OUTPUT, --output OUTPUT
  -c INCLUDE_COLUMNS [INCLUDE_COLUMNS ...], --include-columns INCLUDE_COLUMNS [INCLUDE_COLUMNS ...]
  -x EXCLUDE_COLUMNS [EXCLUDE_COLUMNS ...], --exclude-columns EXCLUDE_COLUMNS [EXCLUDE_COLUMNS ...]
  -p, --pretty
  --indent INDENT
```

## Contributing

csv2json.py welcomes contributions. Please submit PRs & issues as needed. Just don't be a dick.

